@@ -18,6 +18,7 @@ from __future__ import annotations
 import time
 import warnings
 from collections import namedtuple
+from dataclasses import dataclass
 from typing import Dict, List, Optional, Union
 
 import numpy as np
@@ -106,8 +107,8 @@ class Cache:
         self.param_prog = None
         self.inverse_data = None
 
-    def make_key(self, solver, gp, ignore_dpp):
-        return (solver, gp, ignore_dpp)
+    def make_key(self, solver, gp, ignore_dpp, use_quad_obj):
+        return (solver, gp, ignore_dpp, use_quad_obj)
 
     def gp(self):
         return self.key is not None and self.key[1]
@@ -408,6 +409,13 @@ class Problem(u.Canonical):
         """
         return self._solver_stats
 
+    @property
+    def compilation_time(self) -> float | None:
+        """float : The number of seconds it took to compile the problem the
+                   last time it was compiled.
+        """
+        return self._compilation_time
+
     def solve(self, *args, **kwargs):
         """Compiles and solves the problem using the specified method.
 
@@ -626,8 +634,13 @@ class Problem(u.Canonical):
             raise DPPError("Cannot set enforce_dpp = True and ignore_dpp = True.")
 
         start = time.time()
-        # Cache includes ignore_dpp because it alters compilation.
-        key = self._cache.make_key(solver, gp, ignore_dpp)
+        # Cache includes ignore_dpp and solver_opts['use_quad_obj']
+        # because they alter compilation.
+        if solver_opts is None:
+            use_quad_obj = None
+        else:
+            use_quad_obj = solver_opts.get('use_quad_obj', None)
+        key = self._cache.make_key(solver, gp, ignore_dpp, use_quad_obj)
         if key != self._cache.key:
             self._cache.invalidate()
             solving_chain = self._construct_chain(
@@ -886,7 +899,8 @@ class Problem(u.Canonical):
                                        enforce_dpp=enforce_dpp,
                                        ignore_dpp=ignore_dpp,
                                        canon_backend=canon_backend,
-                                       solver_opts=solver_opts)
+                                       solver_opts=solver_opts,
+                                       specified_solver=solver)
 
     @staticmethod
     def _sort_candidate_solvers(solvers) -> None:
@@ -1007,7 +1021,9 @@ class Problem(u.Canonical):
             s.LOGGER.info(
                     'CVXPY will first compile your problem; then, it will '
                     'invoke a numerical solver to obtain a solution.')
-
+            s.LOGGER.info(
+                    "Your problem is compiled with the %s canonicalization backend.",
+                    s.DEFAULT_CANON_BACKEND if canon_backend is None else canon_backend)
         if requires_grad:
             dpp_context = 'dgp' if gp else 'dcp'
             if qcp:
@@ -1398,7 +1414,7 @@ class Problem(u.Canonical):
                     "information.")
 
         self.unpack(solution)
-        self._solver_stats = SolverStats(self._solution.attr,
+        self._solver_stats = SolverStats.from_dict(self._solution.attr,
                                          chain.solver.name())
 
     def __str__(self) -> str:
@@ -1463,6 +1479,7 @@ class Problem(u.Canonical):
     __truediv__ = __div__
 
 
+@dataclass
 class SolverStats:
     """Reports some of the miscellaneous information that is returned
     by the solver after solving but that is not captured directly by
@@ -1483,22 +1500,36 @@ class SolverStats:
         returned directly from the solver, without modification by CVXPY.
         This object may be a dict, or a custom Python object.
     """
-    def __init__(self, results_dict, solver_name: str) -> None:
-        self.solver_name = solver_name
-        self.solve_time = None
-        self.setup_time = None
-        self.num_iters = None
-        self.extra_stats = None
 
-        if s.SOLVE_TIME in results_dict:
-            self.solve_time = results_dict[s.SOLVE_TIME]
-        if s.SETUP_TIME in results_dict:
-            self.setup_time = results_dict[s.SETUP_TIME]
-        if s.NUM_ITERS in results_dict:
-            self.num_iters = results_dict[s.NUM_ITERS]
-        if s.EXTRA_STATS in results_dict:
-            self.extra_stats = results_dict[s.EXTRA_STATS]
+    solver_name: str
+    solve_time: Optional[float] = None
+    setup_time: Optional[float] = None
+    num_iters: Optional[int] = None
+    extra_stats: Optional[dict] = None
 
+    @classmethod
+    def from_dict(cls, attr: dict, solver_name: str) -> "SolverStats":
+        """Construct a SolverStats object from a dictionary of attributes.
+
+        Parameters
+        ----------
+        attr : dict
+            A dictionary of attributes returned by the solver.
+        solver_name : str
+            The name of the solver.
+
+        Returns
+        -------
+        SolverStats
+            A SolverStats object.
+        """
+        return cls(
+            solver_name,
+            solve_time=attr.get(s.SOLVE_TIME),
+            setup_time=attr.get(s.SETUP_TIME),
+            num_iters=attr.get(s.NUM_ITERS),
+            extra_stats=attr.get(s.EXTRA_STATS),
+        )
 
 class SizeMetrics:
     """Reports various metrics regarding the problem.
