@@ -2,6 +2,7 @@ import numpy as np
 import scipy.sparse.linalg as sparla
 
 import cvxpy as cp
+import cvxpy.settings as s
 from cvxpy import psd_wrap
 
 
@@ -38,3 +39,16 @@ def test_is_psd() -> None:
     assert failures == {97}
 
     assert psd_wrap(cp.Constant(P)).is_psd()
+
+
+def test_print():
+    A = cp.Constant(np.ones((3, 3)))
+    assert str(A) == '[[1.00 1.00 1.00]\n [1.00 1.00 1.00]\n [1.00 1.00 1.00]]'
+    B = cp.Constant(np.ones((5, 2)))
+    assert str(
+        B) == '[[1.00 1.00]\n [1.00 1.00]\n ...\n [1.00 1.00]\n [1.00 1.00]]'
+    default = s.PRINT_EDGEITEMS
+    s.PRINT_EDGEITEMS = 10
+    assert str(
+        B) == '[[1.00 1.00]\n [1.00 1.00]\n [1.00 1.00]\n [1.00 1.00]\n [1.00 1.00]]'
+    s.PRINT_EDGEITEMS = default
